aboutsummaryrefslogtreecommitdiff
path: root/libf2c
diff options
context:
space:
mode:
authorRichard Henderson <rth@cygnus.com>1998-04-27 15:53:54 -0700
committerRichard Henderson <rth@gcc.gnu.org>1998-04-27 15:53:54 -0700
commit70e1ce21e5e35bfad92affd8c23a66fe53ed13aa (patch)
treeb86ab27374a52829fa54e04065e57a4e80f30347 /libf2c
parent8746c235643f933be01161215004993606b94a8a (diff)
downloadgcc-70e1ce21e5e35bfad92affd8c23a66fe53ed13aa.zip
gcc-70e1ce21e5e35bfad92affd8c23a66fe53ed13aa.tar.gz
gcc-70e1ce21e5e35bfad92affd8c23a66fe53ed13aa.tar.bz2
* libU77/ltime_.c: Bounce the ftnint argument through a local time_t.
From-SVN: r19457
Diffstat (limited to 'libf2c')
-rw-r--r--libf2c/ChangeLog.egcs4
-rw-r--r--libf2c/libU77/ltime_.c9
2 files changed, 9 insertions, 4 deletions
diff --git a/libf2c/ChangeLog.egcs b/libf2c/ChangeLog.egcs
index d3978cd..81116da 100644
--- a/libf2c/ChangeLog.egcs
+++ b/libf2c/ChangeLog.egcs
@@ -1,3 +1,7 @@
+Mon Apr 27 22:52:31 1998 Richard Henderson <rth@cygnus.com>
+
+ * libU77/ltime_.c: Bounce the ftnint argument through a local time_t.
+
Sun Apr 26 18:07:56 1998 Richard Henderson <rth@cygnus.com>
* configure.in: Adjust include paths in F2C_INTEGER and F2C_LONGINT
diff --git a/libf2c/libU77/ltime_.c b/libf2c/libU77/ltime_.c
index 151ac6c..673a0db 100644
--- a/libf2c/libU77/ltime_.c
+++ b/libf2c/libU77/ltime_.c
@@ -33,14 +33,15 @@ Boston, MA 02111-1307, USA. */
#include "f2c.h"
#ifdef KR_headers
-/* Subroutine */ int G77_ltime_0 (stime, tarray)
- integer *stime, tarray[9];
+/* Subroutine */ int G77_ltime_0 (xstime, tarray)
+ integer *xstime, tarray[9];
#else
/* Subroutine */ int G77_ltime_0 (const integer * stime, integer tarray[9])
#endif
{
struct tm *lt;
- lt = localtime ((time_t *) stime);
+ time_t stime = *xstime;
+ lt = localtime (&stime);
tarray[0] = lt->tm_sec;
tarray[1] = lt->tm_min;
tarray[2] = lt->tm_hour;
@@ -33,14 +33,15 @@ Boston, MA 02111-1307, USA. */
#else
-/* Subroutine */ int G77_ltime_0 (const integer * stime, integer tarray[9])
+/* Subroutine */ int G77_ltime_0 (const integer * xstime, integer tarray[9])
#endif
{